BSV.Tokens.Stas3OutputParams (bsv_sdk v1.4.0)

Copy Markdown View Source

Parameters for a STAS 3.0 output in spend operations.

The optional action_data field allows encoding swap action data or custom data into the output's locking script. For swap principal outputs, this should be nil (neutral marker). For swap remainder outputs, this should inherit from the origin leg's action data.

Summary

Types

t()

@type t() :: %BSV.Tokens.Stas3OutputParams{
  action_data: BSV.Tokens.ActionData.t() | nil,
  confiscatable: boolean(),
  freezable: boolean(),
  frozen: boolean(),
  optional_data: [binary()],
  owner_pkh: <<_::160>>,
  redemption_pkh: <<_::160>>,
  satoshis: non_neg_integer(),
  service_fields: [binary()]
}